Name:           strongswan
Version:        6.0.1
Release:        1%{?dist}
Summary:        IPSec-based VPN solution using IKEv1 and IKEv2

License:        GPLv2
URL:            https://www.strongswan.org/
Source0:        https://download.strongswan.org/strongswan-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gmp-devel
BuildRequires:  openssl-devel
BuildRequires:  libcap-ng-devel
BuildRequires:  pam-devel
BuildRequires:  systemd
BuildRequires:  systemd-devel
BuildRequires:  libselinux-devel
BuildRequires:  iproute
BuildRequires:  curl-devel
BuildRequires:  unbound-devel
BuildRequires:  ldns-devel

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
strongSwan is an OpenSource IPSec-based VPN solution implementing both IKEv1 and IKEv2. It supports modular plugins, modern cryptography, and the VICI interface via `swanctl`.

%package swanctl
Summary:        Modern VICI-based management CLI for strongSwan
Requires:       %{name} = %{version}-%{release}

%description swanctl
Provides `swanctl`, the modern management CLI using the VICI protocol. Required for most deployments with strongSwan 6.x.

%prep
%autosetup

%build
./configure \
    --prefix=%{_prefix} \
    --sbindir=%{_sbindir} \
    --bindir=%{_bindir} \
    --libdir=%{_libdir} \
    --sysconfdir=%{_sysconfdir} \
    --with-systemdsystemunitdir=%{_unitdir} \
    --enable-systemd \
    --enable-swanctl \
    --enable-tools \
    --enable-openssl \
    --enable-pubkey \
    --enable-eap-identity \
    --enable-eap-md5 \
    --enable-eap-mschapv2 \
    --enable-eap-tls \
    --enable-eap-ttls \
    --enable-eap-peap \
    --enable-xauth-eap \
    --enable-xauth-pam \
    --enable-curl \
    --enable-aes \
    --enable-aesni \
    --enable-sha1 \
    --enable-sha2 \
    --enable-sha3 \
    --enable-ctr \
    --enable-curve25519 \
    --enable-chapoly \
    --enable-files \
    --enable-unbound \
    --enable-eap-radius \
    --enable-ext-auth \
    --enable-counters \
    --enable-radattr \
    --disable-gmp

make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/strongswan
mkdir -p %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}%{_libdir}/strongswan

# Copy available top-level docs
for f in README AUTHORS ChangeLog LICENSE COPYING; do
    [ -f "$f" ] && install -m 644 "$f" %{buildroot}%{_docdir}/%{name}/
done

%pre
getent group strongswan >/dev/null || groupadd -r strongswan
getent passwd strongswan >/dev/null || useradd -r -g strongswan -d /etc/strongswan -s /sbin/nologin -c "strongSwan VPN user" strongswan
exit 0

%post
%systemd_post strongswan.service

%preun
%systemd_preun strongswan.service

%postun
%systemd_postun_with_restart strongswan.service

%files
%license COPYING
%doc %{_docdir}/%{name}
%dir %{_sysconfdir}/strongswan
%config(noreplace) %{_sysconfdir}/strongswan.conf
%config(noreplace) %{_sysconfdir}/strongswan.d/
%{_libdir}/ipsec/
%{_libdir}/strongswan/
%{_libexecdir}/ipsec/
%{_unitdir}/strongswan.service
%{_unitdir}/strongswan-starter.service
%{_bindir}/pki
%{_mandir}/man1/pki*.1.gz
%{_mandir}/man5/strongswan.conf.5.gz
%{_datadir}/strongswan/

%files swanctl
%{_sbindir}/swanctl
%{_sbindir}/charon-systemd
%{_mandir}/man8/swanctl.8.gz
%config(noreplace) /etc/swanctl/
%{_mandir}/man5/swanctl.conf.5.gz

%changelog
* Fri Jun 20 2025 Admin <admin@highproxies.io> - 6.0.1-1
- Updated RPM to include all config, plugins, and binaries
- swanctl and charon-systemd packaged
- Legacy ipsec CLI removed (deprecated in v6)
